# Classification with Born's Rule

<img src="https://upload.wikimedia.org/wikipedia/en/thumb/0/08/Logo_for_Conference_on_Neural_Information_Processing_Systems.svg/1200px-Logo_for_Conference_on_Neural_Information_Processing_Systems.svg.png" align="right" height="128"/>This package implements the classifier proposed in:

> Emanuele Guidotti and Alfio Ferrara. Text Classification with Born’s Rule. *Advances in Neural Information Processing Systems*, 2022.

<div align="center">
  [<a href="https://github.com/eguidotti/bornrule">GitHub</a>] - 
  [<a href="https://eguidotti.github.io/bornrule/">Docs</a>] - 
  [<a href="https://openreview.net/pdf?id=sNcn-E3uPHA">Paper</a>] - 
  [<a href="https://nips.cc/media/neurips-2022/Slides/54723.pdf">Slides</a>] - 
  [<a href="https://nips.cc/media/PosterPDFs/NeurIPS%202022/8d7628dd7a710c8638dbd22d4421ee46.png">Poster</a>]
</div>

